@@ -1,7 +1,6 @@
 #' @title Plot standardised indices
 #'
-#' @description Plot a time series containing standardised indices, or a histogram
-#' of the indices.
+#' @description Plot a time series or histogram of standardised indices.
 #'
 #' @param x vector or xts object containing the indices to be plotted.
 #' @param type type of plot (either time series "ts", histogram "hist", or barplot "bar").
@@ -43,27 +42,50 @@
 #' plot_sei(supply_de, type = "hist", title = "German renewable energy production in 2019")
 #' plot_sei(supply_de_std, type = "hist", title = "German SREPI in 2019")
 #'
+#' # type = "hist" and type = "bar both output a histogram of the index values
+#' # type = "hist" can be useful to superimpose densities on top of the histogram
+#' z <- seq(-3.5, 3.5, length.out = length(supply_de_std))
+#' plot_sei(supply_de_std, type = "hist", title = "German SREPI in 2019") +
+#'  ggplot2::geom_line(ggplot2::aes(x = z, y = dnorm(z)), col = "blue")
+#'
+#' # type = "bar" can be useful when the index values are bounded
+#' supply_de_std <- std_index(supply_de, timescale = "hours", index_type = "prob11")
+#' plot_sei(supply_de_std, type = "hist", xlims = c(-1, 1), title = 'type = "hist"')
+#' plot_sei(supply_de_std, type = "bar", xlims = c(-1, 1), title = 'type = "bar"')
+#'
+#'
 #' @name plot_sei
 #' @importFrom stats density
 NULL
 
 #' @rdname plot_sei
 #' @export
-plot_sei <- function(x, type = c("ts", "hist", "bar"), title = NULL, lab = "Std. Index", xlims = NULL, ylims = NULL, n_bins = 30){
+plot_sei <- function(x, type = c("ts", "hist", "bar"), title = NULL, lab = "Std. Index",
+                     xlims = NULL, ylims = NULL, n_bins = 30){
 
   type <- match.arg(type)
 
   if (type == "ts") {
-    df <- zoo::fortify.zoo(x)
-    colnames(df) <- c("date", "x")
-    p <- ggplot2::ggplot(df, ggplot2::aes(x = date, y = x)) +
+    if (xts::is.xts(x)) {
+      df <- zoo::fortify.zoo(x)
+      colnames(df) <- c("date", "x")
+      p <- ggplot2::ggplot(df, ggplot2::aes(x = date, y = x)) +
+        ggplot2::scale_x_datetime(name = "Date", expand = c(0, 0))
+    } else {
+      df <- data.frame(x = x, t = zoo::index(x))
+      p <- ggplot2::ggplot(df, ggplot2::aes(x = t, y = x)) +
+        ggplot2::scale_x_continuous(name = "Time step", expand = c(0, 0))
+    }
+
+    p <- p +
       ggplot2::geom_ribbon(ggplot2::aes(ymin = pmin(x, 0), ymax = 0), fill = "blue", alpha = 0.5) +
       ggplot2::geom_ribbon(ggplot2::aes(ymin = 0, ymax = pmax(x, 0)), fill = "red", alpha = 0.5) +
-      ggplot2::scale_x_datetime(name = "Date", expand = c(0, 0)) +
       ggplot2::scale_y_continuous(name = lab, limits = ylims, expand = c(0, 0)) +
       ggplot2::geom_hline(ggplot2::aes(yintercept = 0), color = "grey", linetype = "dotted") +
       ggplot2::theme_bw() +
+      ggplot2::theme(plot.margin = ggplot2::margin(c(5.5, 10.5, 5.5, 5.5))) +
       ggplot2::ggtitle(title)
+
   } else if (type == "hist") {
     if (xts::is.xts(x)) {
       df <- zoo::fortify.zoo(x)
@@ -78,7 +100,8 @@ plot_sei <- function(x, type = c("ts", "hist", "bar"), title = NULL, lab = "Std.
       ggplot2::theme(panel.grid.major = ggplot2::element_blank(),
                      panel.grid.minor = ggplot2::element_blank(),
                      axis.text.y = ggplot2::element_blank(),
-                     axis.ticks.y = ggplot2::element_blank()) +
+                     axis.ticks.y = ggplot2::element_blank(),
+                     plot.margin = ggplot2::margin(c(5.5, 10.5, 5.5, 5.5))) +
       ggplot2::ggtitle(title)
   } else if (type == "bar") {
 
@@ -93,7 +116,10 @@ plot_sei <- function(x, type = c("ts", "hist", "bar"), title = NULL, lab = "Std.
       ggplot2::scale_x_continuous(name = lab, limits = xlims) +
       ggplot2::scale_y_continuous(name = "Density", limits = ylims, expand = ggplot2::expansion(c(0, 0.05))) +
       ggplot2::theme_bw() +
-      ggplot2::theme(legend.title = ggplot2::element_blank(), panel.grid = ggplot2::element_blank()) +
+      ggplot2::theme(legend.title = ggplot2::element_blank(),
+                     panel.grid = ggplot2::element_blank(),
+                     axis.text.y = ggplot2::element_blank(),
+                     axis.ticks.y = ggplot2::element_blank()) +
       ggplot2::ggtitle(title)
   }
 
